Public core library for Nythos.
nythos-core contains implemented domain models, orchestration services,
and trait contracts only.
It intentionally excludes HTTP, storage drivers, and other infrastructure.
The crate root re-exports the main public surface, with grouped access also
available under auth, domain, ports, rbac, session, and error.
Re-exports
pub use auth::AccessToken;pub use auth::Claims;pub use auth::LoginAuthMaterial;pub use auth::LoginInput;pub use auth::LoginService;pub use auth::PasswordHash;pub use auth::RefreshAuthMaterial;pub use auth::RefreshInput;pub use auth::RefreshService;pub use auth::RegisterAuthMaterial;pub use auth::RegisterInput;pub use auth::RegisterResult;pub use auth::RegisterService;pub use auth::RevokeAllSessionsInput;pub use auth::RevokeAllSessionsService;pub use auth::RevokeResult;pub use auth::RevokeSessionInput;pub use auth::RevokeSessionService;pub use auth::TokenPurpose;pub use domain::Email;pub use domain::Password;pub use domain::RoleId;pub use domain::SessionId;pub use domain::Tenant;pub use domain::TenantId;pub use domain::TenantSettings;pub use domain::User;pub use domain::UserId;pub use domain::UserStatus;pub use error::AuthError;pub use error::NythosResult;pub use ports::NewUser;pub use ports::PasswordHasher;pub use ports::RefreshTokenRotation;pub use ports::RevocationChecker;pub use ports::RoleAssignmentInput;pub use ports::RoleRepository;pub use ports::SessionRecord;pub use ports::SessionStore;pub use ports::TokenSigner;pub use ports::UserCredentials;pub use ports::UserRepository;pub use rbac::Permission;pub use rbac::Role;pub use rbac::RoleAssignment;pub use rbac::RoleRegistry;pub use session::RefreshToken;pub use session::Session;